<?php
namespace Aws\CodeArtifact\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **CodeArtifact** service.
 */
class CodeArtifactException extends AwsException {}
